@@ -1,9 +1,8 @@
-
 /*____________________________________________________________________________
 	
 	FreeAmp - The Free MP3 Player
 
-	Portions Copyright (C) 1998 GoodNoise
+	Portions Copyright (C) 1998-1999 EMusic.com
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -19,16 +18,15 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 	
-	$Id: debug.h,v 1.1.1.1 1998/10/09 00:07:09 jdw Exp $
+	$Id: debug.h,v 1.5 2000/05/25 18:21:24 ijr Exp $
 ____________________________________________________________________________*/
 
-// debug.h
-
-#ifndef _DEBUG_H_
-#define _DEBUG_H_
-
+#ifndef INCLUDED_DEBUG_H_
+#define INCLUDED_DEBUG_H_
 
 void debug_string(char*);
 
+void DebugInit_v(void);
+void Debug_v(const char * format, ...);
 
-#endif // _DEBUG_H_
+#endif /* _DEBUG_H_ */
