@@ -1,9 +1,8 @@
-
 /*____________________________________________________________________________
 	
 	FreeAmp - The Free MP3 Player
 
-	Portions Copyright (C) 1998 GoodNoise
+	Portions Copyright (C) 1998-1999 EMusic.com
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -19,7 +18,7 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 	
-	$Id: mutex.h,v 1.1.1.1 1998/10/09 00:07:09 jdw Exp $
+	$Id: mutex.h,v 1.5 1999/10/19 07:12:48 elrod Exp $
 ____________________________________________________________________________*/
 
 #ifndef MUTEX_H
@@ -32,12 +31,11 @@ ____________________________________________________________________________*/
 class Mutex {
 
 public:
-	Mutex();
-	Mutex(bool createOwned);
+	Mutex(bool createOwned = false);
 	~Mutex();
 
 
-	bool Acquire(unsigned long timeout);
+	bool Acquire(unsigned long timeout = WAIT_FOREVER);
 	void Release();
 
 
