@@ -1,9 +1,8 @@
-
 /*____________________________________________________________________________
 	
 	FreeAmp - The Free MP3 Player
 
-	Portions Copyright (C) 1998 GoodNoise
+	Portions Copyright (C) 1998-1999 EMusic.com
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -19,29 +18,29 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 	
-	$Id: semaphore.h,v 1.1.1.1 1998/10/09 00:07:09 jdw Exp $
+	$Id: semaphore.h,v 1.8 2000/08/10 20:49:37 ijr Exp $
 ____________________________________________________________________________*/
 
-
-
-#ifndef _SEMAPHORE_H_
-#define _SEMAPHORE_H_
+#ifndef INCLUDED_SEMAPHORE_H_
+#define INCLUDED_SEMAPHORE_H_
 				
 #include <windows.h>
 
+#define SEM_LOCKED   0
+#define SEM_UNLOCKED 1
+
 #define WAIT_FOREVER INFINITE
 
 class Semaphore {
- private:
-    int count;
-   	HANDLE m_sem;	
- 
  public:
-    Semaphore(int cnt = 1);
+    Semaphore(int cnt = SEM_LOCKED);
     ~Semaphore();
-    void Wait();
+    bool Wait(int ms = WAIT_FOREVER); // returns false if it times out
     void Signal();
-
+ 
+ private:
+    int m_count;
+   	HANDLE m_sem;	
 };
 
 
