@@ -1,9 +1,8 @@
-
 /*____________________________________________________________________________
 	
 	FreeAmp - The Free MP3 Player
 
-	Portions Copyright (C) 1998 GoodNoise
+	Portions Copyright (C) 1998-1999 EMusic.com
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -19,19 +18,18 @@
 	along with this program; if not, write to the Free Software
 	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 	
-	$Id: semaphore.cpp,v 1.1.1.1 1998/10/09 00:07:09 jdw Exp $
+	$Id: semaphore.cpp,v 1.7 2000/05/04 11:28:31 robert Exp $
 ____________________________________________________________________________*/
 
-
+#include <limits.h>
 
 #include "semaphore.h"
 
-
 Semaphore::Semaphore(int cnt) {
-    count = cnt;
+    m_count = cnt;
     m_sem = CreateSemaphore(NULL, 
-		    				0,
-							cnt,
+		    				cnt,
+							LONG_MAX,
 							""); 
 }
 
@@ -39,8 +37,18 @@ Semaphore::~Semaphore() {
    CloseHandle(m_sem);
 }
 
-void Semaphore::Wait() {	
+bool Semaphore::Wait(int ms) 
+{	
+   if (ms > 0)
+   {
+	   if (WaitForSingleObject(m_sem, ms) == WAIT_TIMEOUT)
+          return false;
+
+      return true;
+   }
+
 	WaitForSingleObject(m_sem, INFINITE);	
+   return true;
 }
 
 void Semaphore::Signal() {
